==> firebase_repository-1.0.34.tar.gz: lib/src/models/carga.dart <==
import 'package:firebase_repository/src/entities/entities.dart';
import 'package:flutter/cupertino.dart';

@immutable
class Carga {
  final String uuid;
  final double agua;
  final double costo;
  final String dietaUuid;
  final double disponibles;
  final DateTime fecha;
  final double materiaSeca;
  final String mixerUuid;
  final double porcentaje;
  final double talcual;
  final double totalcarga;
  final String usuarioUuid;
  final List<dynamic> ingredientes;

  Carga(
      {this.uuid,
      this.agua,
      this.costo,
      this.dietaUuid,
      this.disponibles,
      this.fecha,
      this.materiaSeca,
      this.mixerUuid,
      this.porcentaje,
      this.talcual,
      this.totalcarga,
      this.usuarioUuid,
      this.ingredientes});

  Carga copyWith(
      {String uuid,
      double agua,
      double costo,
      String dietaUuid,
      double disponibles,
      DateTime fecha,
      double materiaSeca,
      String mixerUuid,
      double porcentaje,
      double talcual,
      double totalcarga,
      String usuarioUuid,
      List<dynamic> ingredientes}) {
    return Carga(
      uuid: uuid ?? this.uuid,
      agua: agua ?? this.agua,
      costo: costo ?? this.costo,
      dietaUuid: dietaUuid ?? this.dietaUuid,
      disponibles: disponibles ?? this.disponibles,
      fecha: fecha ?? this.fecha,
      materiaSeca: materiaSeca ?? this.materiaSeca,
      mixerUuid: mixerUuid ?? this.mixerUuid,
      porcentaje: porcentaje ?? this.porcentaje,
      talcual: talcual ?? this.talcual,
      totalcarga: totalcarga ?? this.totalcarga,
      usuarioUuid: usuarioUuid ?? this.usuarioUuid,
      ingredientes: ingredientes ?? this.ingredientes
    );
  }

  @override
  String toString() {
    return 'Carga{uuid: $uuid, agua: $agua, costo: $costo, dietaUuid: $dietaUuid, disponibles: $disponibles, fecha: $fecha, materiaSeca: $materiaSeca, mixerUuid: $mixerUuid, porcentaje: $porcentaje, talcual: $talcual, totalcarga: $totalcarga, usuarioUuid: $usuarioUuid, ingredientes: $ingredientes}';
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
          other is Carga &&
              runtimeType == other.runtimeType &&
              uuid == other.uuid &&
              agua == other.agua &&
              costo == other.costo &&
              dietaUuid == other.dietaUuid &&
              disponibles == other.disponibles &&
              fecha == other.fecha &&
              materiaSeca == other.materiaSeca &&
              mixerUuid == other.mixerUuid &&
              porcentaje == other.porcentaje &&
              talcual == other.talcual &&
              totalcarga == other.totalcarga &&
              usuarioUuid == other.usuarioUuid &&
              ingredientes == other.ingredientes;

  @override
  int get hashCode =>
      uuid.hashCode ^
      agua.hashCode ^
      costo.hashCode ^
      dietaUuid.hashCode ^
      disponibles.hashCode ^
      fecha.hashCode ^
      materiaSeca.hashCode ^
      mixerUuid.hashCode ^
      porcentaje.hashCode ^
      talcual.hashCode ^
      totalcarga.hashCode ^
      usuarioUuid.hashCode ^
      ingredientes.hashCode;

  CargaEntity toEntity(){
    return CargaEntity(
      uuid,
      agua,
      costo,
      dietaUuid,
      disponibles,
      fecha,
      materiaSeca,
      mixerUuid,
      porcentaje,
      talcual,
      totalcarga,
      usuarioUuid,
      ingredientes
    );
  }

  static Carga fromEntity(CargaEntity entity){
    return Carga(
      uuid: entity.uuid,
      agua: entity.agua,
      costo: entity.costo,
      dietaUuid: entity.dietaUuid,
      disponibles: entity.disponibles,
      fecha: entity.fecha,
      materiaSeca: entity.materiaSeca,
      mixerUuid: entity.mixerUuid,
      porcentaje: entity.porcentaje,
      talcual: entity.talcual,
      totalcarga: entity.totalcarga,
      usuarioUuid: entity.usuarioUuid,
      ingredientes: entity.ingredientes
    );
  }



}

==> firebase_repository-1.0.48.tar.gz: lib/src/models/carga.dart <==
import 'package:firebase_repository/src/entities/entities.dart';
import 'package:flutter/cupertino.dart';

@immutable
class Carga {
  final bool activo;
  final String uuid;
  final double agua;
  final double costo;
  final String dietaUuid;
  final double disponibles;
  final DateTime fecha;
  final double materiaSeca;
  final String mixerUuid;
  final double porcentaje;
  final double talcual;
  final double totalcarga;
  final String usuarioUuid;
  final List<dynamic> ingredientes;

  Carga(
      {
        this.activo,
        this.uuid,
      this.agua,
      this.costo,
      this.dietaUuid,
      this.disponibles,
      this.fecha,
      this.materiaSeca,
      this.mixerUuid,
      this.porcentaje,
      this.talcual,
      this.totalcarga,
      this.usuarioUuid,
      this.ingredientes});

  Carga copyWith(
      {bool activo,
        String uuid,
      double agua,
      double costo,
      String dietaUuid,
      double disponibles,
      DateTime fecha,
      double materiaSeca,
      String mixerUuid,
      double porcentaje,
      double talcual,
      double totalcarga,
      String usuarioUuid,
      List<dynamic> ingredientes}) {
    return Carga(
      activo: activo ?? this.activo,
      uuid: uuid ?? this.uuid,
      agua: agua ?? this.agua,
      costo: costo ?? this.costo,
      dietaUuid: dietaUuid ?? this.dietaUuid,
      disponibles: disponibles ?? this.disponibles,
      fecha: fecha ?? this.fecha,
      materiaSeca: materiaSeca ?? this.materiaSeca,
      mixerUuid: mixerUuid ?? this.mixerUuid,
      porcentaje: porcentaje ?? this.porcentaje,
      talcual: talcual ?? this.talcual,
      totalcarga: totalcarga ?? this.totalcarga,
      usuarioUuid: usuarioUuid ?? this.usuarioUuid,
      ingredientes: ingredientes ?? this.ingredientes
    );
  }


  @override
  String toString() {
    return 'Carga{activo: $activo, uuid: $uuid, agua: $agua, costo: $costo, dietaUuid: $dietaUuid, disponibles: $disponibles, fecha: $fecha, materiaSeca: $materiaSeca, mixerUuid: $mixerUuid, porcentaje: $porcentaje, talcual: $talcual, totalcarga: $totalcarga, usuarioUuid: $usuarioUuid, ingredientes: $ingredientes}';
  }


  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
          other is Carga &&
              runtimeType == other.runtimeType &&
              activo == other.activo &&
              uuid == other.uuid &&
              agua == other.agua &&
              costo == other.costo &&
              dietaUuid == other.dietaUuid &&
              disponibles == other.disponibles &&
              fecha == other.fecha &&
              materiaSeca == other.materiaSeca &&
              mixerUuid == other.mixerUuid &&
              porcentaje == other.porcentaje &&
              talcual == other.talcual &&
              totalcarga == other.totalcarga &&
              usuarioUuid == other.usuarioUuid &&
              ingredientes == other.ingredientes;

  @override
  int get hashCode =>
      activo.hashCode ^
      uuid.hashCode ^
      agua.hashCode ^
      costo.hashCode ^
      dietaUuid.hashCode ^
      disponibles.hashCode ^
      fecha.hashCode ^
      materiaSeca.hashCode ^
      mixerUuid.hashCode ^
      porcentaje.hashCode ^
      talcual.hashCode ^
      totalcarga.hashCode ^
      usuarioUuid.hashCode ^
      ingredientes.hashCode;

  CargaEntity toEntity(){
    return CargaEntity(
      activo,
      uuid,
      agua,
      costo,
      dietaUuid,
      disponibles,
      fecha,
      materiaSeca,
      mixerUuid,
      porcentaje,
      talcual,
      totalcarga,
      usuarioUuid,
      ingredientes
    );
  }

  static Carga fromEntity(CargaEntity entity){
    return Carga(
      activo: entity.activo,
      uuid: entity.uuid,
      agua: entity.agua,
      costo: entity.costo,
      dietaUuid: entity.dietaUuid,
      disponibles: entity.disponibles,
      fecha: entity.fecha,
      materiaSeca: entity.materiaSeca,
      mixerUuid: entity.mixerUuid,
      porcentaje: entity.porcentaje,
      talcual: entity.talcual,
      totalcarga: entity.totalcarga,
      usuarioUuid: entity.usuarioUuid,
      ingredientes: entity.ingredientes
    );
  }



}
